@@ -18,6 +18,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+require 'async/io/stream'
+
 require_relative 'transport'
 
 module Async::DNS
@@ -57,8 +59,7 @@ module Async::DNS
 				
 				return @server.process_query(query, options)
 			rescue StandardError => error
-				@logger.error "<> Error processing request: #{error.inspect}!"
-				Async::DNS::log_exception(@logger, error)
+				@logger.error(self, error)
 				
 				return error_response(query)
 			end
@@ -85,7 +86,7 @@ module Async::DNS
 			@logger.debug "<#{response.id}> Writing #{output_data.bytesize} bytes response to client via UDP..."
 			
 			if output_data.bytesize > UDP_TRUNCATION_SIZE
-				@logger.warn "<#{response.id}>Response via UDP was larger than #{UDP_TRUNCATION_SIZE}!"
+				@logger.warn "<#{response.id}> Response via UDP was larger than #{UDP_TRUNCATION_SIZE}!"
 				
 				# Reencode data with truncation flag marked as true:
 				truncation_error = Resolv::DNS::Message.new(response.id)
@@ -114,13 +115,14 @@ module Async::DNS
 		end
 		
 		def handle_connection(socket)
-			input_data = StreamTransport.read_chunk(socket)
+			transport = Transport.new(socket)
 			
-			response = process_query(input_data, remote_address: socket.remote_address)
-			
-			length = StreamTransport.write_message(socket, response)
-			
-			@logger.debug "<#{response.id}> Wrote #{length} bytes via TCP..."
+			while input_data = transport.read_chunk
+				response = process_query(input_data, remote_address: socket.remote_address)
+				length = transport.write_message(response)
+				
+				@logger.debug "<#{response.id}> Wrote #{length} bytes via TCP..."
+			end
 		rescue EOFError => error
 			@logger.warn "<> Error: TCP session ended prematurely!"
 		rescue Errno::ECONNRESET => error
